/*
  +----------------------------------------------------------------------+
  | PHP Version 4                                                        |
  +----------------------------------------------------------------------+
  | Copyright (c) 1997-2002 The PHP Group                                |
  +----------------------------------------------------------------------+
  | This source file is subject to version 2.02 of the PHP license,      |
  | that is bundled with this package in the file LICENSE, and is        |
  | available at through the world-wide-web at                           |
  | http://www.php.net/license/2_02.txt.                                 |
  | If you did not receive a copy of the PHP license and are unable to   |
  | obtain it through the world-wide-web, please send a note to          |
  | license@php.net so we can mail you a copy immediately.               |
  +----------------------------------------------------------------------+
  | Author: Tony Leake tony@webwise-data.co.uk                           |
  +----------------------------------------------------------------------+

  $Id: ecasound.c,v 1.3 2003/01/18 18:28:55 tony Exp $ 
*/

//#define OLD_ECASOUND

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#include "php.h"
#include "php_ini.h"
#include "ext/standard/info.h"
#include "php_ecasound.h"

#ifdef OLD_ECASOUND
#include "ecasound/ecasoundc.h"
#else
#include "libecasoundc/ecasoundc.h"
#endif

/* If you declare any globals in php_ecasound.h uncomment this:
ZEND_DECLARE_MODULE_GLOBALS(ecasound)
*/

/* True global resources - no need for thread safety here */
static int le_ecasound;

/* {{{ ecasound_functions[]
 *
 * Every user visible function must have an entry in ecasound_functions[].
 */
function_entry ecasound_functions[] = {
	PHP_FE(eci_init,	NULL)	
	PHP_FE(eci_cleanup,	NULL)	
	PHP_FE(eci_command,	NULL)	
	PHP_FE(eci_command_float_arg,	NULL)	
	PHP_FE(eci_last_string,	NULL)
	PHP_FE(eci_last_integer,	NULL)
	PHP_FE(eci_last_long_integer,	NULL)
	PHP_FE(eci_last_float,	NULL)
	PHP_FE(eci_error,	NULL)
	PHP_FE(eci_last_error,	NULL)
	PHP_FE(eci_last_string_list_count,	NULL)
	PHP_FE(eci_last_string_list_item,	NULL)
	{NULL, NULL, NULL}	/* Must be the last line in ecasound_functions[] */
};
/* }}} */

/* {{{ ecasound_module_entry
 */
zend_module_entry ecasound_module_entry = {
#if ZEND_MODULE_API_NO >= 20010901
	STANDARD_MODULE_HEADER,
#endif
	"ecasound",
	ecasound_functions,
	PHP_MINIT(ecasound),
	PHP_MSHUTDOWN(ecasound),
	PHP_RINIT(ecasound),		/* Replace with NULL if there's nothing to do at request start */
	PHP_RSHUTDOWN(ecasound),	/* Replace with NULL if there's nothing to do at request end */
	PHP_MINFO(ecasound),
#if ZEND_MODULE_API_NO >= 20010901
	"0.1", /* Replace with version number for your extension */
#endif
	STANDARD_MODULE_PROPERTIES
};
/* }}} */

#ifdef COMPILE_DL_ECASOUND
ZEND_GET_MODULE(ecasound)
#endif

/* {{{ PHP_INI
 */
/* Remove comments and fill if you need to have entries in php.ini
PHP_INI_BEGIN()
    STD_PHP_INI_ENTRY("ecasound.global_value",      "42", PHP_INI_ALL, OnUpdateInt, global_value, zend_ecasound_globals, ecasound_globals)
    STD_PHP_INI_ENTRY("ecasound.global_string", "foobar", PHP_INI_ALL, OnUpdateString, global_string, zend_ecasound_globals, ecasound_globals)
PHP_INI_END()
*/
/* }}} */

/* {{{ php_ecasound_init_globals
 */
/* Uncomment this function if you have INI entries
static void php_ecasound_init_globals(zend_ecasound_globals *ecasound_globals)
{
	ecasound_globals->global_value = 0;
	ecasound_globals->global_string = NULL;
}
*/
/* }}} */

/* {{{ PHP_MINIT_FUNCTION
 */
PHP_MINIT_FUNCTION(ecasound)
{
	/* If you have INI entries, uncomment these lines 
	ZEND_INIT_MODULE_GLOBALS(ecasound, php_ecasound_init_globals, NULL);
	REGISTER_INI_ENTRIES();
	*/
	return SUCCESS;
}
/* }}} */

/* {{{ PHP_MSHUTDOWN_FUNCTION
 */
PHP_MSHUTDOWN_FUNCTION(ecasound)
{
	/* uncomment this line if you have INI entries
	UNREGISTER_INI_ENTRIES();
	*/
	return SUCCESS;
}
/* }}} */

/* Remove if there's nothing to do at request start */
/* {{{ PHP_RINIT_FUNCTION
 */
PHP_RINIT_FUNCTION(ecasound)
{
	return SUCCESS;
}
/* }}} */

/* Remove if there's nothing to do at request end */
/* {{{ PHP_RSHUTDOWN_FUNCTION
 */
PHP_RSHUTDOWN_FUNCTION(ecasound)
{
	return SUCCESS;
}
/* }}} */

/* {{{ PHP_MINFO_FUNCTION
 */
PHP_MINFO_FUNCTION(ecasound)
{
	php_info_print_table_start();
	php_info_print_table_header(2, "ecasound support", "enabled");
	php_info_print_table_end();

	/* Remove comments if you have entries in php.ini
	DISPLAY_INI_ENTRIES();
	*/
}
/* }}} */

const char* _php_last_string_list_item(int n)
{
	return eci_last_string_list_item(n);
}
/* {{{ proto string eci_last_string_list_item(int item_number)
              returns the nth string item that was returned by eci_command */
PHP_FUNCTION(eci_last_string_list_item)
{
	long number;

	if( zend_parse_parameters(ZEND_NUM_ARGS() TSRMLS_CC, "l", &number ) !=SUCCESS) {
		return;
	}

	RETURN_STRING( _php_last_string_list_item( number ), 1 );
}
/* }}} */

int  _php_last_string_list_count(void)
{
	return eci_last_string_list_count();
}
/* {{{ proto int eci_last_string_list_count(void)
              Returns the number of strings returned by the last command */
PHP_FUNCTION(eci_last_string_list_count)
{
	RETURN_LONG( _php_last_string_list_count() );
}
/* }}} */

void _php_command_float_arg(char *command, double arg)
{
	eci_command_float_arg( command, arg );
}
/* {{{ proto void eci_command_float_arg(String command, Double argument)
 	Issue an EIAM command. This function can be used instead of command(string), if the command in question requires exactly one numerical parameter. This way it's possible to avoid the extra string -> float conversion, which would lead to lost precision */
PHP_FUNCTION(eci_command_float_arg)
{
	char *command;
	int command_length;
	double arg;
	
	if( zend_parse_parameters(ZEND_NUM_ARGS() TSRMLS_CC, "sd", &command, &command_length,&arg) !=SUCCESS ) {
		return;
	}
	
	_php_command_float_arg( command, (double)arg );  
}
/* }}} */

long _php_last_long_integer()
{
	return  eci_last_long_integer();
}
/* {{{ proto int eci_last_long_integer(void) Returns the last long integer return value. */
PHP_FUNCTION( eci_last_long_integer )
{
	RETURN_LONG( _php_last_long_integer() );
}

/* }}} */

long _php_last_integer()
{
	return (long) eci_last_integer();
}

/* {{{ proto int eci_last_integer(void) Returns the last integer return value. */
PHP_FUNCTION( eci_last_integer )
{
	RETURN_LONG( _php_last_integer() );
}

/* }}} */


double _php_last_float()
{
	return ( double ) eci_last_float();
}
/* {{{ proto float eci_last_float(void) Returns the last float return value. */
PHP_FUNCTION( eci_last_float )
{
	RETURN_DOUBLE( _php_last_float() );
}

/* }}} */

void _php_eca_init()
{
	eci_init();
}

/* {{{ proto void eci_init(void) Reserve resources for Ecasound */
PHP_FUNCTION( eci_init )
{
	_php_eca_init();
}
/* }}} */

void _php_eci_cleanup()
{
	eci_cleanup();
}
/* {{{ proto void eci_cleanup(void) Free all reserved resources */
PHP_FUNCTION( eci_cleanup )
{
	 _php_eci_cleanup();
}

/* }}} */


void _php_eci_command( char *string )
{
	eci_command(string);
}
/* {{{ proto void eci_command(void) Issue an Ecasound Interactive Mode command*/
PHP_FUNCTION( eci_command )
{
	char *string;
	long string_len;
	
	if ( zend_parse_parameters( ZEND_NUM_ARGS() TSRMLS_CC, "s", &string, &string_len ) !=SUCCESS ) {
		return;
	}

	_php_eci_command( string );
  
}
/* }}} */

long _php_eci_error()
{
	return eci_error();
}
/* {{{ proto int eci_error(void) Returns true (!= 0) if error has occured during the execution of last  command.  Otherwise returns false (= 0).*/
PHP_FUNCTION( eci_error )
{
	RETURN_LONG( _php_eci_error() );
}

/* }}} */

char * _php_last_string()
{
	return eci_last_string();
}
/* {{{ proto string eci_last_string(void) Returns the last string return value. */
PHP_FUNCTION( eci_last_string )
{
	RETURN_STRING( _php_last_string(), 1 );
}

/* }}} */


char * _php_last_error()
{
	return eci_last_error();
}
/* {{{ proto String eci_last_error(void)  Returns a string describing the last error. 
         If the last EIAM command was executed succesfully, returns an empty string */
PHP_FUNCTION( eci_last_error )
{
	RETURN_STRING( _php_last_error(), 1 );
}

/* }}} */

/*
 * Local variables:
 * tab-width: 4
 * c-basic-offset: 4
 * End:
 * vim600: noet sw=4 ts=4 fdm=marker
 * vim<600: noet sw=4 ts=4
 */
